@@ -1,6 +1,22 @@
+# <opa: An Implementation of Ordinal Pattern Analysis.>
+# Copyright (C) <2022>  <Timothy Beechey; tim.beechey@protonmail.com>
+#
+# This program is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
+
+
+
 row_pcc <- function(xs, h, pairing_type, diff_threshold) {
-  # skip NAs in the data row
-  xs_no_nas <- stats::na.omit(xs)
   # if there are NAs in the data row, skip corresponding
   # values in the hypothesis
   if (any(is.na(xs))) {
@@ -27,11 +43,11 @@ row_pcc <- function(xs, h, pairing_type, diff_threshold) {
 
 pcc <- function(dat, h, pairing_type, diff_threshold) {
 
-  individual_pccs <- numeric(nrow(dat))
+  individual_pccs <- numeric(dim(dat)[1])
   total_pairs <- 0
   correct_pairs <- 0
 
-  for (r in 1:nrow(dat)) {
+  for (r in 1:dim(dat)[1]) {
     result <- row_pcc(dat[r,], h, pairing_type, diff_threshold)
     individual_pccs[r] <- result$pcc
     total_pairs <- total_pairs + result$n_pairs
